@@ -47,10 +47,10 @@ TwitterTopBar::TwitterTopBar(QGraphicsWidget *parent)
     _refreshButton = new TwitterButton(TwitterButton::Refresh, "", this);
 
     // Home Button
-    _homeButton = new TwitterButton(TwitterButton::Generic, "Home",NULL);
+    _homeButton = new TwitterButton(TwitterButton::Home, "", NULL);
 
     // Mentions Button
-    _mentionsButton = new TwitterButton(TwitterButton::Generic, "@",NULL);
+    _mentionsButton = new TwitterButton(TwitterButton::Mentions, "", NULL);
 
     // Add Buttons to List
     _buttonsList->addToList(_homeButton);
