@@ -27,11 +27,13 @@
 
 #include <QtNetwork>
 
-#include "twitterapplicationitem.h"
+#include "account/accountManager.h"
+
+#include "applicationItems/twitterapplicationitem.h"
+#include "applicationItems/twitterbutton.h"
+#include "applicationItems/kineticlist.h"
+
 #include "imagedownload.h"
-#include "twitterbutton.h"
-#include "kineticlist.h"
-#include "account.h"
 #include "backend.h"
 
 /*! \class TwitterTopBar
