@@ -21,6 +21,7 @@
  */
 
 #include "backend.h"
+#include "account/accountManager.h"
 
 /*! \namespace Connection Contains types of connections.
   */
@@ -74,6 +75,7 @@ void Backend::_deleteEntry(quint64 id)
 void Backend::_credentials(EntryList entries)
 {
     _userInformations = entries.at(0).userInfo;
+    AccountManager::instance()->setUser(&_userInformations);
     emit signedOn();
 }
 
